Learn R Programming

bonn (version 1.0.3)

get_geographies: Get Available Geographies

Description

get_geographies either retrieves a data frame with all available geographies or all existing units for a given geography

Usage

get_geographies(geography = NULL)

Value

a data.frame either with the columns Kurzname (geography name), ID (geography identifier) and NGeb (number of units) or with the columns Schlüssel (unit identifier) and Name (unit name).

Arguments

geography

geography as string or NULL

Examples

Run this code

# The SSL vertification seems to fail for some Linux systems. 
# This is likely because of a SSL certificate issue on the INKAR server. 
# Disabling SSL verification comes with risks: 
# https://curl.se/libcurl/c/CURLOPT_SSL_VERIFYPEER.html
httr::set_config(httr::config(ssl_verifypeer = 0L))

# Available geographies  
get_geographies()

# All districts 
get_geographies("KRS")

# Reset configuration  
httr::reset_config()

Run the code above in your browser using DataLab