Learn R Programming

bonn (version 1.0.3)

get_themes: Get Available Themes

Description

get_themes retrieves a data frame with all available themes

Usage

get_themes(geography)

Value

a data.frame with columns ID (theme identifier), Bereich (theme name) and Unterbereich (sub-theme name).

Arguments

geography

geography as character string

Details

To get a list of available geographies use get_geographies.

See Also

get_geographies

Examples

Run this code

# The SSL vertification seems to fail for some Linux systems. 
# This is likely because of a SSL certificate issue on the INKAR server. 
# Disabling SSL verification comes with risks: 
# https://curl.se/libcurl/c/CURLOPT_SSL_VERIFYPEER.html
httr::set_config(httr::config(ssl_verifypeer = 0L))

# Available themes  
get_themes("KRE")

# Reset configuration  
httr::reset_config()



Run the code above in your browser using DataLab